@@ -56,9 +56,8 @@ liqcell *ciroclock_create()
     // Mon Aug 31 21:51:41 2009 lcuk : still need to handle real cleanup, but that bridge will come later.
     
 		liqcell *timer1=liqcell_quickcreatevis("timer1",   "liqtimer",   0,0,   0,0 );
-		liqcell_handleradd(timer1,"timertick",timer_tick);
+		liqcell_handleradd_withcontext(timer1,"timertick",timer_tick,self);
 		liqcell_propseti(timer1,"timerinterval", 250 );
-		
 		liqcell_setenabled(timer1,1);
 		liqcell_child_insert( self,timer1);
 
