@@ -32,7 +32,7 @@
 
 	static int widget_click(liqcell *self, liqcellclickeventargs *args, void *context)
 	{
-		args->newdialogtoopen = self;//liqcell_child_lookup( self, "body" );
+		args->newdialogtoopen = liqcell_hold( self );//liqcell_child_lookup( self, "body" );
 		return 1;
 	}
 
